Re: Prevent auto scan in wireless devices

2009-01-14 Thread Aloisio Almeida
On Wed, Jan 14, 2009 at 5:54 PM, Dan Williams  wrote:
> On Wed, 2009-01-14 at 17:35 -0300, Aloisio Almeida wrote:
>>
>> The main question is why lead to user the responsibility to save power
>> if (in my point of view) nm can do it automatically. The "power
>
> It shouldn't be up to the user, the system should be optimized for
> maximum power saving already.  This means that if the wifi isn't being
> actively used, the system shouldn't be powering the card on.  That
> should be transparent to the user and requires no changes to
> NetworkManager.

Ok, so you're saying that the user or system should take care about
the power saving. In this case we should have a "power saving daemon"
turning on/off the wireless card following some policies. Some
requirements of this daemon:

1. In boot time, if the daemon want to keep my wireless card off, nm
shouldn't turn it on when launching.
2. To turn off automatically the wireless card after 2 minutes
disconnected (a example of power saving rule) the daemon should get
the "wireless connection disconnected" information by listen a nm
signal.

I mean, this daemon needs information that nm has and this daemon does
operations on devices that we suppose to leave nm manage. So, why
don't we make nm manage these things based on "power saving mode" set
by system/user configurations? Why should we leave 2 different
applications to control the wireless card power?

>> saving" mode could be activated by user, by default or by an event
>> came from power system management and it can prevent the system to
>> waste power. Think as a embedded system user, you want a device that
>> its default behavior is always save power.
>
> Again, is scanning while associated *actually* wasting power?

I've never tested this, my guess is: it doesn't

> If the user isn't using wifi, then the chip doesn't need to be
> turned on, and NetworkManager will ignore it and not scan.

As I said before, in my point of view, we should leave just NM handle
the power of wireless cards.

>> As I said before, "no scanning" was the first idea to save power, it's
>> not the main goal. I want a device that has a huge battery life. Turn
>> on features only when asked by user is a good way. NM ( the wireless
>> manager) can do this turning the wireless card off after some time
>> disconnected and turn it on when user ask for it by user.
>
> Yep.  You can certainly do this with a "turn wifi on" / "turn wifi off"
> sort of thing in the UI, which most embedded devices have anyway.  There
> are other ways to achieve the same functionality without having that
> sort of user choice either.
>
> But at the end of the day, if you want to save power, you'll want to
> turn off the wifi chipset when the user isn't going to use it.
>
>> I prefer to loose 2 or 3 seconds to get the first list of available
>> APs than loose battery life during the X minutes (or hours) scanning
>> and keeping the wireless card on. In desktops it doesn't matter, in
>> notebooks it maybe doesn't affect so much, but in a embedded system i
>> already noticed that it matters...
>
> Again, does it *really* save power to not scan when the wifi is already
> active?

Maybe my sentence was a little bit confusing, let me clarify. I am not
saying that "not scan when the wifi is already active saves power" I
am saying that when I don't want to connect to wireless network i also
don't want to waste power keeping my wireless card on.

And yeah, using Nokia ITs (N800, N810) running Mamona distribution
(with nm) is VERY easy to notice that with wireless card on, the
battery life goes down deeply. Maybe the driver and/or device is not
that good, this is a thing that I need to check. But anyway wireless
is a RF device, so it consume very much power for a embedded device.
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: Prevent auto scan in wireless devices

2009-01-14 Thread Aloisio Almeida
On Wed, Jan 14, 2009 at 4:49 PM, Dan Williams  wrote:
> On Wed, 2009-01-14 at 16:29 -0300, Aloisio Almeida wrote:
>> Well, you're right about stop background scans, it seems to change the
>> way that NM was structured to work.
>>
>> But lets suppose the use case where you have a embedded system (or a
>> notebook/netbook) and you're running on battery and you don't want use
>> wireless that time and you don't have a rf switch button. You will
>> loose power keeping your wireless card on scanning at each 20 seconds,
>> using passive scan or not.
>
> There are always mechanisms to turn off the card if you don't have a
> hardware switch; the largest hammer is to 'rmmod' the driver module.
> The second largest hammer is to power the card down with 'iwconfig wlanX
> txpower off' or something like that.  The third is to mark the
> connection as not managed by NetworkManager during the time that you
> want the wifi to be "off".

The main question is why lead to user the responsibility to save power
if (in my point of view) nm can do it automatically. The "power
saving" mode could be activated by user, by default or by an event
came from power system management and it can prevent the system to
waste power. Think as a embedded system user, you want a device that
its default behavior is always save power.

> None of these require a hardware rfkill switch.  They all accomplish
> what (I understand) you want:  no scanning when the user isn't connected
> to an AP.
>

As I said before, "no scanning" was the first idea to save power, it's
not the main goal. I want a device that has a huge battery life. Turn
on features only when asked by user is a good way. NM ( the wireless
manager) can do this turning the wireless card off after some time
disconnected and turn it on when user ask for it by user.

I prefer to loose 2 or 3 seconds to get the first list of available
APs than loose battery life during the X minutes (or hours) scanning
and keeping the wireless card on. In desktops it doesn't matter, in
notebooks it maybe doesn't affect so much, but in a embedded system i
already noticed that it matters...
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: Prevent auto scan in wireless devices

2009-01-14 Thread Aloisio Almeida
Well, you're right about stop background scans, it seems to change the
way that NM was structured to work.

But lets suppose the use case where you have a embedded system (or a
notebook/netbook) and you're running on battery and you don't want use
wireless that time and you don't have a rf switch button. You will
loose power keeping your wireless card on scanning at each 20 seconds,
using passive scan or not.

Why don't activate a POWER SAVING mode in nm (when running on battery)
and make it decrease the power consumption by turning the wireless
card off after X seconds disconnected and only turn it on by client
request?


On Wed, Jan 14, 2009 at 2:02 PM, Dan Williams  wrote:
> On Tue, 2009-01-13 at 23:17 +0200, Antti Kaijanmäki wrote:
>> [Aloisio, sorry for double reply, I forgot to CC the list]
>>
>> On Tue, 2009-01-13 at 17:45 -0300, Aloisio Almeida wrote:
>> > Hi all,
>> >
>> > I noticed that wireless devices are always scanning, and this is very
>> > bad to power consuption in embedded systems.
>> > I would like to create a way to prevent automatic scan and just
>> > perform it when some cliente ask for it.
>> > Is it possible to do this? I mean, does it "brake" in some way the nm 
>> > structure?
>>
>> Sounds good. Actually if you look at some current embedded devices they
>> are performing wireless scan only after user has indicated he wants to
>> create a wireless connection.
>
> I tend to think this is mainly because "it's always been done this way"
> rather than for the reason that it's actually a smoother experience for
> users.  Chips used to suck enough that they actually did require more
> power to scan, but these days with passive scans, you don't even need to
> TX, and thus you don't need to increase power that much.  If this is
> really a concern, the best approach is to simply disable the device (or
> rfkill or whatever) until the user wants to use it, at which point you
> bring the device out of rfkill and let NM go wild.
>
>> > Actually, I already did this patch to 0.6.6 version, but zero lines
>> > applied in new code :) Now i would like to create the patch and submit
>> > to upstream.
>> >
>> > The basic idea is just make can_scan function (src/nm-device-wifi.c)
>> > return FALSE due to some user configurations or run flags
>> > (--no-bg-scan). In this case, "performScan" dbus method and
>> > "ScanPerformed" dbus signal must be created to allow clients to ask
>> > for a scan and to notice that the scan has been performed.
>>
>> Would those be added in org.freedesktop.NetworkManager interface or per
>> wireless device in Device.Wireless?
>
> Not going to happen...  Again, we don't just toss stuff in before
> actually *understanding* what the problem is, and then determining if
> there are better ways of solving the problem instead of these sorts of
> hacks.
>
>> > I'm attaching the 0.6.6 patch, as I said before the idea is the same.
>> >
>> > Any comments? Is it a good way to implement that?
>>
>> I would like to have also a dbus option which you can change without
>> restarting the daemon; setScanningEnabled() or something like that.
>> '--no-bg-scan' would initialize it as false on daemon startup. It could
>> be changed during system operation based on power profiles or something
>> like that. Anyway it would give more flexibility. Of course that could
>> be too close to wirelessEnabled (), though...
>
> Again, what's the use-case here?  Are there better ways of solving this
> issue that don't impact the roaming ability performance or user
> experience?
>
> Dan
>
>
>
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: Prevent auto scan in wireless devices

2009-01-14 Thread Aloisio Almeida
Hey Tony,

Before come to work I was thinking exactly the same. Actually prevent
the background scan is not the main point. We must save power. Why
would you have a wireless card that does nothing? Turn it off.

I think nm should have a kind of SAVE_POWER profiling that can be
automatically activated when running on battery, and in this mode it
could turn the wireless card off when disconnected and turn it on only
by client request, for instance.

When activated, the scan interleaving times could be increased to all
modes, but i don't know if this is really necessary.

Another thing to discuss is if the frequent firmware load/unload can
brings us some problem or not.


On Tue, Jan 13, 2009 at 6:53 PM, Tony Espy  wrote:
> Aloisio Almeida wrote:
>>
>> Hi all,
>>
>> I noticed that wireless devices are always scanning, and this is very
>> bad to power consuption in embedded systems.
>
> Having looked at Wi-Fi power consumption last year while working on a MID
> project, we did some measurements with a Marvell SD8686 card and found that
> backing off the scanning didnd't really save all that much power compared to
> when the device was associated with an AP and PS-Mode was enabled.
>
> This led us to the conclusion that the only way to really save power while
> unassociated ( at least with the SD8686 ) was to toggle the power to the
> card when NM was in it's inactive phase ( ie. not associated, and not
> currently scanning ).
>
> I haven't looked to closely at NM 0.7 to see how applicable this approach
> is, but if I get some time, I'll try and do so...
>
>> Any comments? Is it a good way to implement that?
>
> In the past, Dan has stated that he's against making scanning directly
> controllable via DBUS.
>
> Ciao,
> /tony
>
>
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: Prevent auto scan in wireless devices

2009-01-13 Thread Aloisio Almeida
>
> Would those be added in org.freedesktop.NetworkManager interface or per
> wireless device in Device.Wireless?
>

If you think that you can use one card as wifi client, and another as
AP, placing this in Device.Wireless prevent useless scans on the "AP
card".
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Prevent auto scan in wireless devices

2009-01-13 Thread Aloisio Almeida
Hi all,

I noticed that wireless devices are always scanning, and this is very
bad to power consuption in embedded systems.
I would like to create a way to prevent automatic scan and just
perform it when some cliente ask for it.
Is it possible to do this? I mean, does it "brake" in some way the nm structure?

Actually, I already did this patch to 0.6.6 version, but zero lines
applied in new code :) Now i would like to create the patch and submit
to upstream.

The basic idea is just make can_scan function (src/nm-device-wifi.c)
return FALSE due to some user configurations or run flags
(--no-bg-scan). In this case, "performScan" dbus method and
"ScanPerformed" dbus signal must be created to allow clients to ask
for a scan and to notice that the scan has been performed.

I'm attaching the 0.6.6 patch, as I said before the idea is the same.

Any comments? Is it a good way to implement that?

Tks
Aloisio
Index: NetworkManager-0.6.6/src/nm-device-802-11-wireless.c
===
--- NetworkManager-0.6.6.orig/src/nm-device-802-11-wireless.c	2008-09-05 15:01:32.0 -0300
+++ NetworkManager-0.6.6/src/nm-device-802-11-wireless.c	2008-09-08 11:37:23.0 -0300
@@ -624,9 +624,12 @@
 	NMDevice80211Wireless *	self = NM_DEVICE_802_11_WIRELESS (dev);
 	GSource *source;
 	guintsource_id;
+NMData *app_data;
+
+app_data = nm_device_get_app_data (NM_DEVICE (self));
 
 	/* Start the scanning timeout for devices that can do scanning */
-	if (nm_device_get_capabilities (dev) & NM_DEVICE_CAP_WIRELESS_SCAN) {
+	if (!app_data->no_scan && nm_device_get_capabilities (dev) & NM_DEVICE_CAP_WIRELESS_SCAN) {
 		/* Stupid orinoco has problems scanning immediately after being up,
 		 * so wait a bit before triggering a scan.
 		 */
@@ -1063,9 +1066,14 @@
  NMWirelessScanInterval interval)
 {
 	guint8 seconds = nm_wireless_scan_interval_to_seconds (interval);
+	NMData *app_data;
 
 	g_return_if_fail (self != NULL);
 
+	app_data = nm_device_get_app_data (NM_DEVICE (self));
+	if (app_data->no_scan)
+		return;
+
 	self->priv->scan_interval = seconds;	
 
 	if (interval == NM_WIRELESS_SCAN_INTERVAL_ACTIVE && !self->priv->scanning) {
@@ -1974,9 +1982,13 @@
 scan_results_timeout (NMDevice80211Wireless *self)
 {
 	GTimeVal cur_time;
+NMData * app_data;
 
 	g_return_val_if_fail (self != NULL, FALSE);
 
+app_data = nm_device_get_app_data (NM_DEVICE (self));
+g_assert (app_data);
+
 	request_and_convert_scan_results (self);
 
 	self->priv->scanning = FALSE;
@@ -1984,11 +1996,39 @@
 	g_get_current_time (&cur_time);
 	self->priv->last_scan = cur_time.tv_sec;
 
-	/* After the first successful scan back down to the ACTIVE scan interval */
-	if (self->priv->scan_interval == nm_wireless_scan_interval_to_seconds (NM_WIRELESS_SCAN_INTERVAL_INIT))
-		nm_device_802_11_wireless_set_scan_interval (self, NM_WIRELESS_SCAN_INTERVAL_ACTIVE);
-	else
-		schedule_scan (self, 0);
+if (!app_data->no_scan)
+{
+	/* After the first successful scan back down to the ACTIVE scan interval */
+	if (self->priv->scan_interval == nm_wireless_scan_interval_to_seconds (NM_WIRELESS_SCAN_INTERVAL_INIT))
+		nm_device_802_11_wireless_set_scan_interval (self, NM_WIRELESS_SCAN_INTERVAL_ACTIVE);
+	else
+		schedule_scan (self, 0);
+}
+else
+{
+/* If we're in "no scan" mode, lets always signalize that we've performed a scan */
+DBusMessage *message;
+char*dev_path = NULL;
+
+if (!(dev_path = nm_dbus_get_object_path_for_device (NM_DEVICE (self
+goto out;
+
+if (!(message = dbus_message_new_signal (NM_DBUS_PATH, NM_DBUS_INTERFACE, "ScanPerformed")))
+{
+nm_warning ("scan_results_timeout(): Not enough memory for new dbus message!");
+goto out;
+}
+
+dbus_message_append_args (message, DBUS_TYPE_OBJECT_PATH, &dev_path, DBUS_TYPE_INVALID);
+
+if (!dbus_connection_send (app_data->dbus_connection, message, NULL))
+nm_warning ("scan_results_timeout(): Could not raise the ScanPerformed signal!");
+
+dbus_message_unref (message);
+
+out:
+g_free (dev_path);
+}
 
 	return FALSE;
 }
@@ -2134,7 +2174,7 @@
 		}
 		schedule_scan_results_timeout (self, 10);
 	}
-	return FALSE;
+	return TRUE;
 
 reschedule:
 	schedule_scan (self, 0);
@@ -2156,6 +2196,13 @@
 }
 
 
+gboolean
+nm_device_802_11_wireless_perform_scan (NMDevice80211Wireless *self)
+{
+return nm_device_802_11_wireless_scan ((gpointer) self);
+}
+
+
 /*
  * schedule_scan
  *
Index: NetworkManager-0.6.6/src/NetworkManager.c
===
--- NetworkManager-0.6.6.orig/src/NetworkManager.c	2008-0

Re: Connecton on APs with weak signal quality

2006-11-07 Thread Aloisio
On 11/6/06, Dan Williams <[EMAIL PROTECTED]> wrote:

> However, this is never going to be a solution because what's the upper
> bound?  If you're at the margins of the network, maybe 1/2 your packets
> get lost during the handshakes and assoc/auth, and the association takes
> a really long time.  The delay is already something like 40 seconds, and
> that's _waaay_ too long already.  If you cannot associate to your
> network within 20 seconds, you either need to be closer to your AP or
> you need to get your network admin to fix stuff.

Yes, I agree. But using nm I get connection some times (after lot of
tries) and after this the connection is stable. The problem is getting
connection and not keep connected... So I guess that the problem is
not only the signal quality, but the set: low quality + lot os APs +
hidden SSID.

> At the same time, moving NM to talking to wpa_supplicant over DBus will
> eliminate a lot of the overhead of the current socket-based method, and
> also remove the lag when spawning a copy of wpa_supplicant.  So there's
> definitely room to take the latency of the connection down in
> NetworkManager itself.  But perpetually increasing the connection
> timeout because "it's just not long enough for my situation" isn't the
> right answer in the medium or long run.

I'm using CVS version, it's already using DBus, right?

Aloisio

> Dan
>
> > Thanks
> > Aloisio
> > ___
> > NetworkManager-list mailing list
> > NetworkManager-list@gnome.org
> > http://mail.gnome.org/mailman/listinfo/networkmanager-list
>
>
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: Connecton on APs with weak signal quality

2006-11-06 Thread Aloisio
On 11/6/06, Darren Albers <[EMAIL PROTECTED]> wrote:
> On 11/6/06, Aloisio <[EMAIL PROTECTED]> wrote:
> > Oooww
> >
> > Anybody know answers to some of these questions ??? I use nm is these
> > conditions in most part of time...
> >
>
> Network Manager attempts to associate and if it fails to do so in the
> timeout period it does not try again.  If the signal is so weak that
> connecting is tough then it is doubtful that NM could keep the
> connection up.   It might be an interesting feature request to create
> a "Keep trying" option but I can't imagine it being of much use, if
> you have such a problem connecting you will probably have a hard time
> maintaining a connection.

OK, this "keep trying" would simulate what wpasupplicant do... I think
that maybe this could be a behaviour instead of a option. If it's not
connect in anywhere and there are known SSID (and hidden SSID) in scan
list, nm could keep trying to connect to preferred network... just a
suggestion... Maybe not useful to most people, but...

> If the issue is that NM is just timing out before the connection is
> made then we can help you increase that timeout in the source by
> yourself.
>

Yes, could solve my problem. I will increase this timeout and include
the "keep try" option. Any directions?

Thanks
Aloisio
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: Connecton on APs with weak signal quality

2006-11-06 Thread Aloisio
Oooww

Anybody know answers to some of these questions ??? I use nm is these
conditions in most part of time...

Thanks again
Aloisio


On 11/1/06, Aloisio <[EMAIL PROTECTED]> wrote:
> Hi all,
>
> I've realized a big difference between nm and wpa_supplicant (command
> line) behavior when I trying to connect on weak signal wireless
> conections. Actually this environment has also hidden SSID and more
> than one physical AP. I don't know yet where is (are) the problem(s).
> What I know is that wpa_supplicant launched by command line can always
> connect and using nm I need a lot of tries to get success. Sometimes I
> give up...
>
> I know that wpa_supplicant tries "without stop" to associate to known
> scanned SSID and to "scan_ssid=1" SSIDs and wpa_supplicant spend some
> tries to get success. My questions are: how many times nm tries to
> connect to one AP when I choose on item on a list or when a use "other
> wireless connection" ? Can nm tries more times if needs (i.e. if
> detect fail by timeout or if detect that signal quality is low)?
>
> Thanks!
> Aloisio
>
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Connecton on APs with weak signal quality

2006-11-01 Thread Aloisio
Hi all,

I've realized a big difference between nm and wpa_supplicant (command
line) behavior when I trying to connect on weak signal wireless
conections. Actually this environment has also hidden SSID and more
than one physical AP. I don't know yet where is (are) the problem(s).
What I know is that wpa_supplicant launched by command line can always
connect and using nm I need a lot of tries to get success. Sometimes I
give up...

I know that wpa_supplicant tries "without stop" to associate to known
scanned SSID and to "scan_ssid=1" SSIDs and wpa_supplicant spend some
tries to get success. My questions are: how many times nm tries to
connect to one AP when I choose on item on a list or when a use "other
wireless connection" ? Can nm tries more times if needs (i.e. if
detect fail by timeout or if detect that signal quality is low)?

Thanks!
Aloisio
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Re: NetworkManager with hidden ESSID

2006-11-01 Thread Aloisio
Hi,

Do you know if there has more than one AP with same SSID in the same
place?? In large places this is necessary to provide enought signal
quality. If in the last time you have connected to AP with mac address
X, nm make an association between X and the SSID, right ? But when it
gets scan results, you can have X, Y and W APs providing connection
and both with same SSID, and both hidden. The question is: in this
case, what nm do ? I will able to connect only on X AP (if the SSID
appear in list)? Can nm associate more than one mac address to a SSID
? The SSID does not appear because Y or W have more sinal quality than
X ?

Here where I work, the same thing happens and here we have more than
one AP providing wireless connections.

Thanks
Aloisio

On 11/1/06, Dan Williams <[EMAIL PROTECTED]> wrote:
> On Wed, 2006-11-01 at 10:41 +0100, Riko Wichmann wrote:
> > Dear all,
> >
> > I have a problem with NetworkManager at work, where the APs don't
> > broadcast their ESSID. At home, where I don't hide the ESSID, there is
> > no problem.
>
> Does the AP show up in the scan list if you do a manual "iwlist ethX
> scan" as root?
>
> > So, here it goes: I'm running NetworkManager on a Dell D600 and really
> > like it, especially the dispatcher feature. However, when I'm at work,
> > the internal wireless network does not show up in the list that the
> > nm-applet provides. I can connect to it without problem using the
> > 'Connect to other wireless networks' option. Then it shows in the list.
> > However, next time I reboot the machine and look into the applet, the
> > internal network is gone again from the list. It's a WEP encrypted
> > network, if that makes any difference.
> >
> > in ~/.gconf/system/networking/wireless/networks I find a configuration
> > for the network, but it never shows up. It kind of defeats the purpose
> > of NetworkManager, if you need to configure the same network all the
> > time again.
>
> Does the AP's bssid (looks like a MAC address) show up in the "bssids"
> key in the saved settings for that wireless network?  NM caches the
> BSSID of base stations it's connected to for each wireless network, and
> then reverse-matches those to the BSSIDs it finds in the scan list, and
> that's how it finds hidden SSID access points.  We need to figure out
> which part here is breaking down.
>
> Dan
>
> > I googeled already, but didn't find any answer.
> >
> > Am I completely optimistic to assume, that the network should show up,
> > once it was configured correctly? Is there any solution for that?
> > The way it is now, it's useless for me :(
> >
> > I'm running Ubuntu Dapper Drake and tried both the default network
> > manager version, which is 0.6.0 and the lastest (0.6.4) one compiled
> > form sources.
> >
> > Thanks and cheers,
> >
> >   a very frustrated Riko
> >
> > ___
> > NetworkManager-list mailing list
> > NetworkManager-list@gnome.org
> > http://mail.gnome.org/mailman/listinfo/networkmanager-list
>
> ___
> NetworkManager-list mailing list
> NetworkManager-list@gnome.org
> http://mail.gnome.org/mailman/listinfo/networkmanager-list
>
___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list


Madwifi issues

2006-10-02 Thread Aloisio
HiI've just joined on nm maillist. First of all congratulations! The design goals of project are amazing.Actualy I want to provide a set of deb packages to make nm works perfectly on ubuntu in thinkpads (and in long term, in everywhere). I need a solution to support madwifi and ipw drivers, leap authentication and everything in Ubuntu Dapper version. I have some questions:
- I've noticed that the cvs version does not support madwifi drivers but I know that there is a workarround. I don't know why this fix is not integrated yet but I can imagine that you have already discussed a lot about it, so I want to know where you've discussed this to take a look (if someone want to explain me, it would be perfect).
- I'm experiencing A LOT of issues with madwifi driver, probably there are madwifi users here. Is the problem nm, wpa_supplicant or madwifi driver ? Are you prefer use ndiswrapper instead of madwifi ?Thanks
Aloisio AlmeidaSoftware EngineerLTC - IBM Brazil

___
NetworkManager-list mailing list
NetworkManager-list@gnome.org
http://mail.gnome.org/mailman/listinfo/networkmanager-list